# What is Nano++?

NPP, or Nano++ for short is a text editor designed for those vaguely familiar with the Nano text editor, but are frustrated with the shortcomings of it - and don't want to go through learning Vim or Emacs.

For example npp includes more familiar text selection, copying to clipboard and is a whole LETTER shorter than typing out nano.

Installation should be fairly simple:

Initialise a virtual environment and `pip install nanoplusplus`

Now when you have that virtual environment activated, NPP will be available to use!